@@ -13,10 +13,10 @@ from trytond.tools import grouped_slice, reduce_ids
 
 
 __all__ = ['Party']
-__metaclass__ = PoolMeta
 
 
 class Party:
+    __metaclass__ = PoolMeta
     __name__ = 'party.party'
 
     deposit = fields.Function(fields.Numeric('Deposit'),
@@ -28,7 +28,7 @@ class Party:
         MoveLine = pool.get('account.move.line')
         Account = pool.get('account.account')
         User = pool.get('res.user')
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
 
         line = MoveLine.__table__()
         account = Account.__table__()
@@ -97,20 +97,16 @@ class Party:
         'Return the deposit account balance (debit - credit) for the party'
         pool = Pool()
         MoveLine = pool.get('account.move.line')
-        Account = pool.get('account.account')
-        cursor = Transaction().cursor
+        transaction = Transaction()
+        cursor = transaction.connection.cursor()
 
         line = MoveLine.__table__()
-        account = Account.__table__()
-
         assert deposit_account.kind == 'deposit'
 
-        cursor.lock(MoveLine._table)
-
-        cursor.execute(*line.join(account, condition=account.id == line.account
-                ).select(
+        transaction.database.lock(transaction.connection, MoveLine._table)
+        cursor.execute(*line.select(
                 Sum(Coalesce(line.debit, 0) - Coalesce(line.credit, 0)),
-                where=(account.id == deposit_account.id)
+                where=(line.account == deposit_account.id)
                 & (line.party == self.id)
                 & (line.reconciliation == Null)))
         amount, = cursor.fetchone()
